'
' Licensed Materials - Property of IBM
' 5748-XX8
' (c) Copyright International Business Machines Corp. 2006
' All Rights Reserved
' US Government Users Restricted Rights - Use, duplication or disclosure
' restricted by GSA ADP Schedule Contract with IBM Corp.
'
option explicit

'
' Script to configure / unconfigure the environment for the FIM Plug-in.
'

'
' Usage: fimpienvcfg -action config
'        fimpienvcfg -action unconfig
'

Public Const FIMPI_REG_PATH  = "Software\IBM\Tivoli Federated Identity Manager\6.1.1.0\WebServerPlugin"
Public Const CCSENV_REG_PATH = "System\CurrentControlSet\Control\Session Manager\Environment"
        
' The main line
Dim action
action = getAction()

If action = "config" Then
        performConfig
ElseIf action = "unconfig" Then
        performUnconfig
Else
        WScript.echo "Invalid action (" & action & ") specified."
        printUsage
End If

' Prints out a usage message
Sub printUsage
        WScript.echo "fimpienvcfg.vbs : Configure / unconfigure the environment for the FIM Plug-in"
        WScript.echo "fimpienvcfg.vbs -action config"
        WScript.echo "fimpienvcfg.vbs -action unconfig"
End Sub

' Retrieves the action the user specified on the command line
Function getAction
        If WScript.Arguments.Count < 2 Then
                getAction = ""
        ElseIf not WScript.Arguments.Item(0) = "-action" Then
                getAction = ""
        Else
                getAction = WScript.Arguments.Item(1)
        End If
End Function

'
' Perform a configuration of the environment
'
Sub performConfig
        dim basePath, nlsPath
        dim currentPath, newPath
        
        basePath = left(WScript.ScriptFullName, len(WScript.ScriptFullName) - (len(WScript.ScriptName) + len("bin\")))
        nlsPath = basePath & "nls"
        currentPath = getRegistryValue("HKLM\" & CCSENV_REG_PATH & "\Path")
        newPath = currentPath
        If not Right(newPath, 1) = ";" Then
                newPath = newPath & ";"
        End If
        newPath = newPath & basePath & "bin\" & ";"
        
        ' Set our configuration values
        createHKLMRegistryKey FIMPI_REG_PATH
        setHKLMRegistryValue  FIMPI_REG_PATH, "BasePath", basePath
        setHKLMRegistryValue  FIMPI_REG_PATH, "ConfigFile", basePath & "etc\fimpi.conf"
        
        ' Set the system-wide configuration values
        setHKLMRegistryValue CCSENV_REG_PATH, "NLSPATH", nlsPath
        setHKLMExpandedRegistryValue CCSENV_REG_PATH, "Path", newPath
End Sub

'
' Perform an unconfiguration of the environment
'
Sub performUnconfig
        Dim currentPath, newPath
        Dim basePath, fimpiBinPath, offset

        ' Remove the FIM Plug-in's bin/ directory from the $PATH
        currentPath = getRegistryValue("HKLM\" & CCSENV_REG_PATH & "\Path")
        basePath = left(WScript.ScriptFullName, len(WScript.ScriptFullName) - (len(WScript.ScriptName) + len("bin\")))
        fimpiBinPath = basePath & "bin\;"
        newPath = Replace(currentPath, fimpiBinPath, "")
        If not newPath = currentPath Then
                setHKLMExpandedRegistryValue CCSENV_REG_PATH, "Path", newPath
        End If
        
        ' Remove the NLSPATH  system-wide configuration 
        deleteHKLMRegistryValue CCSENV_REG_PATH, "NLSPATH"

        ' Remove the FIMPI configuration node
        deleteHKLMRegistryKey FIMPI_REG_PATH

End Sub

'
' This subroutine creates a path in the HKEY_LOCAL_MACHINE section
' of the Windows registry
'
' \param path : The path relative to HKLM\ to create
' 
sub createHKLMRegistryKey(path)
        const HKEY_LOCAL_MACHINE = &H80000002
        dim regObj
        set regObj = GetObject("winmgmts:\\localhost\root\default:StdRegProv")
        regObj.CreateKey HKEY_LOCAL_MACHINE, path
end Sub

'
' This subroutine deletes a path in the HKEY_LOCAL_MACHINE section
' of the Windows registry
'
' \param path : The path relative to HKLM\ to delete
'
Sub deleteHKLMRegistryKey(path)
        Const HKEY_LOCAL_MACHINE = &H80000002
        Dim regObj
        Set regObj = GetObject("winmgmts:\\localhost\root\default:StdRegProv")
        regObj.DeleteKey HKEY_LOCAL_MACHINE, path
End Sub

'
' This subroutine sets a string value in the HKEY_LOCAL_MACHINE section 
' of the Windows registry.
'
' \param path  : The path relative to HKLM\ to put the value in
' \param name  : The name of the key to create
' \param value : The value to specify for the key
'
sub setHKLMRegistryValue(path, name, value)
        const HKEY_LOCAL_MACHINE = &H80000002
        dim regObj
        set regObj = GetObject("winmgmts:\\localhost\root\default:StdRegProv")
        regObj.SetStringValue HKEY_LOCAL_MACHINE, path, name, value
end sub

' As above, but sets a string that needs to have variables expanded when
' used.
sub setHKLMExpandedRegistryValue(path, name, value)
        const HKEY_LOCAL_MACHINE = &H80000002
        dim regObj
        set regObj = GetObject("winmgmts:\\localhost\root\default:StdRegProv")
        regObj.SetExpandedStringValue HKEY_LOCAL_MACHINE, path, name, value
end Sub

'
' This subroutine deletes a value from in the HKEY_LOCAL_MACHINE section
' of the Windows registry
'
' \param path : The path relative to HKLM\ that the value is in
' \param name : The name of the value to delete
'
Sub deleteHKLMRegistryValue(path, name)
        const HKEY_LOCAL_MACHINE = &H80000002
        dim regObj
        set regObj = GetObject("winmgmts:\\localhost\root\default:StdRegProv")    
        regObj.deleteValue HKEY_LOCAL_MACHINE, path, Name
End Sub

'
' This function gets the value associated with the registry path specified
'
' \param path : The registry path to get the value for.
'
function getRegistryValue (path)
        dim shellObj
        set shellObj = WScript.CreateObject("WScript.Shell")
        getRegistryValue = shellObj.RegRead(path)
end function
