# @(#)11  1.9 src/cmdline/staging/scripts/import_partner.py, amws.cmdline, fim611, 060921a 9/18/06 16:18:28
# (C) Copyright International Business Machines Corporation 2005. All rights
# reserved.  U.S. Government Users Restricted Rights -- Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 
from fim_base import read_properties_file, commit_session, prepare_mgr_objs
from fed_utils import get_federation, import_partner, get_partner, get_partners
from domain_utils import is_domain_present
from com.tivoli.am.fim.logging import FIMLoggerFactory
from com.tivoli.am.fim.logging import FIMLogger
from com.tivoli.am.fim.logging import FIMLevel
from com.tivoli.am.fim.i18n.msgs import CmdLineMessages
from jarray import array
from java.lang import Object
from com.tivoli.am.fim.logging import FIMLoggerConstants

# Set up FIMLogger
component_name = "StagingTools"
script_name = "import_partner.py"
method_name = script_name
class_name = "com.tivoli.am.fim.cmdline." + script_name[0:-3]
FIMLoggerFactory.enableStdout(FIMLevel.ALL)
FIMLoggerFactory.setPreferredFIMLoggerImpl(FIMLoggerConstants.FIMLOGGER_BASE_IMPL)
log = FIMLoggerFactory.getFIMLogger(component_name, class_name, CmdLineMessages.CLASS_NAME)

def usage():
    inserts = array([script_name],Object)
    log.logMessage(FIMLevel.INFO, method_name, CmdLineMessages.usage_import_partner, \
        inserts)
    raise SystemExit
    
if __name__ == 'main':

    if len(sys.argv) < 5:
        usage()

    src_props_file = sys.argv[0]
    targ_props_file = sys.argv[1]
    user_props_file = sys.argv[2]
    fed_name = sys.argv[3]
    partner_name = sys.argv[4]
    
    src_props = read_properties_file(src_props_file)
    if not is_domain_present(src_props):
        raise SystemExit 

    # Get the source federation object and federation manager
    (src_fed, src_fed_mgr) = get_federation(fed_name, src_props_file, 
        "import_partner_src_fed")
    if not src_fed:
        inserts = array([fed_name], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.federation_does_not_exist, inserts)
        raise SystemExit

    # Get the target federation object and federation manager
    target_props = read_properties_file(targ_props_file)
    if not is_domain_present(target_props):
        raise SystemExit 
    (targ_fed, targ_fed_mgr) = get_federation(fed_name, targ_props_file, 
        "import_partner_targ_fed")   
    if not targ_fed:
        inserts = array([fed_name], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.federation_does_not_exist, inserts)
        raise SystemExit

    # Get user-defined properties for the federation 
    user_props = read_properties_file(user_props_file)

    # If the user properties file sets DisplayName, then that will be
    # the name of the new partner, so we have to set the name here
    # before checking whether a partner by that name exists. 
    if user_props.has_key("DisplayName"):
        old_partner_name = partner_name
        new_partner_name = user_props["DisplayName"]
    else:
        old_partner_name = new_partner_name = partner_name

    # Check to see if partner already exists
    targ_partner_dict = get_partners(targ_fed)
    if new_partner_name in targ_partner_dict.values():
        inserts = array([new_partner_name, fed_name], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.partner_already_exists, inserts)
        raise SystemExit

    # Import the partner to the target federation with the supplied properties
    import_partner(src_fed, targ_fed, user_props, old_partner_name)

    # Check to see if partner got imported
    targ_partner_dict = get_partners(targ_fed)
    if new_partner_name in targ_partner_dict.values():
        inserts = array([new_partner_name, fed_name], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.imported_partner_successfully, inserts)
    else:
        targ_props = read_properties_file(targ_props_file)
        inserts = array([old_partner_name, fed_name, targ_props["Domain"]], Object)
        log.logMessage(FIMLevel.INFO, method_name, \
            CmdLineMessages.unable_to_import_partner, inserts)
        raise SystemExit
    
    # Commit changes
    commit_session(targ_fed_mgr)
    
    
